{ inputs, lib, config, pkgs, ... }:

{
  imports =
    [
      "/etc/nixos/hardware-configuration.nix"
      inputs.xremap-flake.nixosModules.default
    ];

  nix = {
    settings = {
      experimental-features = [ "nix-command" "flakes" ];
    };
  };

  time.timeZone = "Europe/Stockholm";

  i18n = {
    defaultLocale = "sv_SE.UTF-8";

    extraLocaleSettings = {
      LC_ADDRESS = "sv_SE.UTF-8";
      LC_IDENTIFICATION = "sv_SE.UTF-8";
      LC_MEASUREMENT = "sv_SE.UTF-8";
      LC_MONETARY = "sv_SE.UTF-8";
      LC_NAME = "sv_SE.UTF-8";
      LC_NUMERIC = "sv_SE.UTF-8";
      LC_PAPER = "sv_SE.UTF-8";
      LC_TELEPHONE = "sv_SE.UTF-8";
      LC_TIME = "sv_SE.UTF-8";
    };
  };

  users.users = {
    thomas = {
      isNormalUser = true;
      description = "Thomas";
      extraGroups = [ "networkmanager" "wheel" "docker" ];
# Also groups "uinput" and "input" for xremap to work with home-manager?
      packages = with pkgs; [ ];
      shell = pkgs.fish;
    };
  };
  # Enable automatic login for the user.
  services.displayManager.autoLogin = {
    enable = true;
    user = "thomas";
  };
  systemd.services."getty@tty1".enable = false;
  systemd.services."autovt@tty1".enable = false;

  # Enable the X11 windowing system.
  services.xserver.enable = true;

  # Enable the GNOME Desktop Environment.
  services.xserver.displayManager.gdm.enable = true;
  services.xserver.desktopManager.gnome.enable = true;

  services.xremap = {
    userName = "thomas";
    withGnome = true;
# Macbook Pro keyboard:
# ctrl alt cmd space   cmd alt
# 29   56  125 <space> 126 100
# KEY_LEFTCTRL KEY_LEFTALT KEY_LEFTMETA KEY_RIGHTMETA KEY_RIGHTALT
    yamlConfig = ''
      modmap:
        - name: Caps lock fix
          remap:
            CapsLock:
              held: leftctrl
              alone: Esc
              alone_timeout_millis: 150
        - name: Space super
          remap:
            Space:
              held: KEY_RO
              alone: Space
      virtual_modifiers:
        - KEY_RO
      keymap:
        - remap:
            KEY_RO-a: key_1
            KEY_RO-s: key_2
            KEY_RO-d: key_3
            KEY_RO-f: key_4
            KEY_RO-g: key_5
    '';
  };

  # Remap right alt to left alt so both can be used for special characters
  #services.xserver.displayManager.sessionCommands = "sleep 5 && ${pkgs.xorg.xmodmap}/bin/xmodmap -e 'keycode 100 = keycode 65' &";

  services.xserver.xkb = {
    layout = "se";
    variant = "mac";
  };
  console.keyMap = "sv-latin1";

  # Enable CUPS to print documents.
  services.printing.enable = true;

  # Enable sound with pipewire.
  hardware.pulseaudio.enable = false;
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
  };

  # Enable touchpad support (enabled default in most desktopManager).
  # services.xserver.libinput.enable = true;


  # Allow unfree packages
  nixpkgs.config.allowUnfree = true;
  virtualisation.docker.enable = true;

  programs = {
    firefox.enable = true;
    neovim = {
      enable = true;
      defaultEditor = true;
      vimAlias = true;
    };
    fish.enable = true;
    git.enable = true;
    tmux.enable = true;
  };

  environment.systemPackages = with pkgs; [
    vscode
    neovim
    xorg.xmodmap
    docker-compose
    kitty
  ];

  # Enable the OpenSSH daemon.
  services.openssh.enable = true;

  system.stateVersion = "24.11"; # Did you read the comment?

}
